.. _contributing:

================================
Contributing to validations-libs
================================

If you're interested in contributing to the validations-libs project,
the following will help get you started.

#tripleo on Freenode IRC Network
--------------------------------
There is a very active chat channel at irc://freenode.net/#tripleo.
This is usually the best place to ask questions and find your way around.
IRC stands for Internet Relay Chat and it is a way to chat online in real
time. You can ask a question and come back later to read the answer in the
log files. Logs for the #tripleo IRC channel are stored at
http://eavesdrop.openstack.org/irclogs/%23tripleo/.

Contributor License Agreement
-----------------------------

.. index::
   single: license; agreement

In order to contribute to the validations-libs project, you need to have
signed OpenStack's contributor's agreement.

.. seealso::

   * https://docs.openstack.org/infra/manual/developers.html
   * https://wiki.openstack.org/wiki/CLA

Project Hosting Details
-----------------------

Code Hosting
    https://opendev.org/openstack/validations-libs

Code Review
    https://review.opendev.org/#/q/status:open+project:openstack/validations-libs,n,z
